@@ -10,6 +10,8 @@ if is_py2:
     str = unicode
     basestring = basestring
     input = raw_input
+    builtin_int = int
+    int = long
 else:
     from io import StringIO, BytesIO
     builtin_str = str
@@ -17,3 +19,5 @@ else:
     bytes = bytes
     basestring = (str, bytes)
     input = input
+    builtin_int = int
+    int = int
