@@ -16,6 +16,8 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
+from __future__ import print_function
+
 import logging
 logging.basicConfig(level=logging.WARN)
 
@@ -24,12 +26,13 @@ import base64
 import bs4
 import cgi
 import dxpy
-from dx_build_app import parse_destination
+from dxpy.compat import BytesIO
+from .dx_build_app import parse_destination
 import imghdr
 import json
 import os
 import re
-import urllib2
+from dxpy.packages import requests
 
 parser = argparse.ArgumentParser(description="Constructs and saves/uploads an HTML report from HTML and/or linked images")
 parser.add_argument("src", help="Source image or HTML file(s)", nargs="+")
@@ -115,9 +118,9 @@ def _load_url(url):
     Loads a URL resource from a remote server
     """
     try:
-        response = urllib2.urlopen(url)
-        return response
-    except urllib2.URLError as ex:
+        response = requests.get(url)
+        return BytesIO(response.content)
+    except IOError as ex:
         parser.error("{url} could not be loaded remotely! ({ex})".format(url=url, ex=ex))
 
 
@@ -242,7 +245,7 @@ def main(**kwargs):
     if len(remote_file_ids) > 0:
         json_out = {"fileIds": remote_file_ids}
         json_out["recordId"] = create_record(args.remote, remote_file_ids, args.width, args.height)
-        print json.dumps(json_out)
+        print(json.dumps(json_out))
 
 
 if __name__ == "__main__":
